@@ -16,7 +16,7 @@ from aim.engine.configs import (
 
 
 class Session:
-    sessions: Dict[str, List['Session']] = {}
+    sessions = {}  # type: Dict[str, List['Session']] = {}
 
     @exception_resistant
     def __init__(self, repo: Optional[str] = None,
@@ -33,6 +33,8 @@ class Session:
         self.metrics = {}
 
         self.active = True
+        self._run_hash = self.repo.active_commit
+        self._repo_path = self.repo.path
 
         # Finalize run
         atexit.register(self.close)
@@ -41,6 +43,14 @@ class Session:
     def __del__(self):
         self.close()
 
+    @property
+    def run_hash(self):
+        return self._run_hash
+
+    @property
+    def repo_path(self):
+        return self._repo_path
+
     @exception_resistant
     def close(self):
         if self.active:
